==> libreoffice-4.4.7.2.tar.xz: libreoffice-4.4.7.2/wizards/com/sun/star/wizards/common/NoValidPathException.java <==
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

package com.sun.star.wizards.common;

import com.sun.star.lang.XMultiServiceFactory;

public class NoValidPathException extends Exception
{
    public NoValidPathException(XMultiServiceFactory xMSF, String _sText)
    {
        super(_sText);
        // TODO: NEVER open a dialog in an exception
        if (xMSF != null)
        {
            SystemDialog.showErrorBox(xMSF, "dbwizres", "dbw", 521); // OfficePathnotavailable
        }
    }

    public NoValidPathException(XMultiServiceFactory xMSF, String _sText, Throwable cause)
    {
        super(_sText, cause);
        // TODO: NEVER open a dialog in an exception
        if (xMSF != null)
        {
            SystemDialog.showErrorBox(xMSF, "dbwizres", "dbw", 521); // OfficePathnotavailable
        }
    }
}

==> libreoffice_5.1.2.orig.tar.xz: libreoffice-5.1.2/wizards/com/sun/star/wizards/common/NoValidPathException.java <==
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

package com.sun.star.wizards.common;

import com.sun.star.lang.XMultiServiceFactory;

public class NoValidPathException extends Exception
{
    public NoValidPathException(XMultiServiceFactory xMSF, String _sText)
    {
        super(_sText);
        // TODO: NEVER open a dialog in an exception
        if (xMSF != null)
        {
            SystemDialog.showErrorBox(xMSF, "dbw", 521); // OfficePathnotavailable
        }
    }

    public NoValidPathException(XMultiServiceFactory xMSF, String _sText, Throwable cause)
    {
        super(_sText, cause);
        // TODO: NEVER open a dialog in an exception
        if (xMSF != null)
        {
            SystemDialog.showErrorBox(xMSF, "dbw", 521); // OfficePathnotavailable
        }
    }
}
